==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/ReferencedAttributesFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReferencedAttributesFluent<A extends ReferencedAttributesFluent<A>> extends Fluent<A>{


    public A addToAttributeMatches(int index,AttributeMatch item);
    public A setToAttributeMatches(int index,AttributeMatch item);
    public A addToAttributeMatches(AttributeMatch... items);
    public A addAllToAttributeMatches(Collection<AttributeMatch> items);
    public A removeFromAttributeMatches(AttributeMatch... items);
    public A removeAllFromAttributeMatches(Collection<AttributeMatch> items);
    
/**
 * This method has been deprecated, please use method buildAttributeMatches instead.
 * @return The buildable object.
 */
@Deprecated public List<AttributeMatch> getAttributeMatches();
    public List<AttributeMatch> buildAttributeMatches();
    public AttributeMatch buildAttributeMatch(int index);
    public AttributeMatch buildFirstAttributeMatch();
    public AttributeMatch buildLastAttributeMatch();
    public AttributeMatch buildMatchingAttributeMatch(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    public A withAttributeMatches(List<AttributeMatch> attributeMatches);
    public A withAttributeMatches(AttributeMatch... attributeMatches);
    public Boolean hasAttributeMatches();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> addNewAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> addNewAttributeMatchLike(AttributeMatch item);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> setNewAttributeMatchLike(int index,AttributeMatch item);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editAttributeMatch(int index);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editFirstAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editLastAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editMatchingAttributeMatch(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    public A addToWords(int index,String item);
    public A setToWords(int index,String item);
    public A addToWords(String... items);
    public A addAllToWords(Collection<String> items);
    public A removeFromWords(String... items);
    public A removeAllFromWords(Collection<String> items);
    public List<String> getWords();
    public String getWord(int index);
    public String getFirstWord();
    public String getLastWord();
    public String getMatchingWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withWords(List<String> words);
    public A withWords(String... words);
    public Boolean hasWords();

    public interface AttributeMatchesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AttributeMatchFluent<ReferencedAttributesFluent.AttributeMatchesNested<N>>{

        
    public N and();    public N endAttributeMatch();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/mixer/v1/ReferencedAttributesFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReferencedAttributesFluent<A extends ReferencedAttributesFluent<A>> extends Fluent<A>{


    public A addToAttributeMatches(int index,AttributeMatch item);
    public A setToAttributeMatches(int index,AttributeMatch item);
    public A addToAttributeMatches(AttributeMatch... items);
    public A addAllToAttributeMatches(Collection<AttributeMatch> items);
    public A removeFromAttributeMatches(AttributeMatch... items);
    public A removeAllFromAttributeMatches(Collection<AttributeMatch> items);
    public A removeMatchingFromAttributeMatches(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildAttributeMatches instead.
 * @return The buildable object.
 */
@Deprecated public List<AttributeMatch> getAttributeMatches();
    public List<AttributeMatch> buildAttributeMatches();
    public AttributeMatch buildAttributeMatch(int index);
    public AttributeMatch buildFirstAttributeMatch();
    public AttributeMatch buildLastAttributeMatch();
    public AttributeMatch buildMatchingAttributeMatch(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    public Boolean hasMatchingAttributeMatch(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    public A withAttributeMatches(List<AttributeMatch> attributeMatches);
    public A withAttributeMatches(AttributeMatch... attributeMatches);
    public Boolean hasAttributeMatches();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> addNewAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> addNewAttributeMatchLike(AttributeMatch item);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> setNewAttributeMatchLike(int index,AttributeMatch item);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editAttributeMatch(int index);
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editFirstAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editLastAttributeMatch();
    public ReferencedAttributesFluent.AttributeMatchesNested<A> editMatchingAttributeMatch(io.fabric8.kubernetes.api.builder.Predicate<AttributeMatchBuilder> predicate);
    public A addToWords(int index,String item);
    public A setToWords(int index,String item);
    public A addToWords(String... items);
    public A addAllToWords(Collection<String> items);
    public A removeFromWords(String... items);
    public A removeAllFromWords(Collection<String> items);
    public List<String> getWords();
    public String getWord(int index);
    public String getFirstWord();
    public String getLastWord();
    public String getMatchingWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingWord(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withWords(List<String> words);
    public A withWords(String... words);
    public Boolean hasWords();
    public A addNewWord(String arg1);
    public A addNewWord(StringBuilder arg1);
    public A addNewWord(StringBuffer arg1);

    public interface AttributeMatchesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AttributeMatchFluent<ReferencedAttributesFluent.AttributeMatchesNested<N>>{

        
    public N and();    public N endAttributeMatch();
}


}
